package com.pjilisense.flxai.controller;

import com.pjilisense.flxai.base.constant.Constant;
import com.pjilisense.flxai.dto.FilesDTO;
import com.pjilisense.flxai.page.PageData;
import com.pjilisense.flxai.utils.Result;
import com.pjilisense.flxai.dto.ChunksDTO;
import com.pjilisense.flxai.service.ChunksService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import springfox.documentation.annotations.ApiIgnore;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import javax.servlet.http.HttpServletResponse;
import java.util.List;
import java.util.Map;


/**
 * ${comments}
 *
 * @author liushujing liushujing@philisense.com
 * @since 1.0.0 2025-02-10
 */
@RestController
@RequestMapping(Constant.BASE_PATH+"chunks")
@Api(tags="${comments}")
public class ChunksController {

    private static Logger logger = LoggerFactory.getLogger(ChunksController.class);

    @Autowired
    private ChunksService chunksService;

    @GetMapping("page")
    @ApiOperation("分页")
    @ApiImplicitParams({
        @ApiImplicitParam(name = Constant.PAGE, value = "当前页码，从1开始", paramType = "query", required = true, dataType="Integer", dataTypeClass =Integer.class) ,
        @ApiImplicitParam(name = Constant.LIMIT, value = "每页显示记录数", paramType = "query",required = true, dataType="Integer", dataTypeClass =Integer.class) ,
        @ApiImplicitParam(name = Constant.ORDER_FIELD, value = "排序字段", paramType = "query", dataType="String", dataTypeClass =String.class) ,
        @ApiImplicitParam(name = Constant.ORDER, value = "排序方式，可选值(asc、desc)", paramType = "query", dataType="String", dataTypeClass =String.class)
    })
    public Result<PageData<ChunksDTO>> page(@ApiIgnore @RequestParam Map<String, Object> params){
        PageData<ChunksDTO> page = chunksService.page(params);

        return new Result<PageData<ChunksDTO>>().ok(page);
    }

    @GetMapping("{id}")
    @ApiOperation("信息")
    public Result<ChunksDTO> get(@PathVariable("id") Long id){
        ChunksDTO data = chunksService.get(id);

        return new Result<ChunksDTO>().ok(data);
    }
    @PostMapping("/search")
    @ApiOperation("模糊检索")
    public Result searchByText(@RequestBody ChunksDTO dto){
        List<Map<String,Object>> list =chunksService.search(dto.getUserId(),dto.getText());
        return new Result().ok(list);
    }
    @PostMapping
    @ApiOperation("保存")
    public Result save(@RequestBody ChunksDTO dto){
        chunksService.save(dto);

        return new Result();
    }

    @PutMapping
    @ApiOperation("修改")
    public Result update(@RequestBody ChunksDTO dto){

        chunksService.update(dto);

        return new Result();
    }

    @DeleteMapping
    @ApiOperation("删除")
    public Result delete(@RequestBody Long[] ids){
        //效验数据
        chunksService.delete(ids);

        return new Result();
    }

}