package com.pjilisense.flxai.handle;

import org.apache.ibatis.type.BaseTypeHandler;

import java.sql.CallableStatement;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.UUID;

/**
 * UUID类型处理器
 */
public class UUIDTypeHandler extends BaseTypeHandler<UUID> {

    /**
     * 获取结果
     *
     * @param resultSet  resultSet
     * @param columnName 列名
     * @return UUID结果
     * @throws SQLException SQL异常
     */
    @Override
    public UUID getNullableResult(ResultSet resultSet, String columnName)
            throws SQLException {
        return getValue(resultSet.getString(columnName));
    }


    /**
     * 获取结果
     *
     * @param rs          结果集
     * @param columnIndex 列下标
     * @return UUID结果
     * @throws SQLException SQL异常
     */
    @Override
    public UUID getNullableResult(ResultSet rs, int columnIndex) throws SQLException {
        return getValue(rs.getString(columnIndex));
    }


    /**
     * 获取结果
     *
     * @param cs          cs
     * @param columnIndex 列下标
     * @return 返回UUID结果
     * @throws SQLException SQL异常
     */
    @Override
    public UUID getNullableResult(CallableStatement cs, int columnIndex)
            throws SQLException {
        return getValue(cs.getString(columnIndex));
    }


    /**
     * 设置参数
     *
     * @param ps        ps
     * @param i         i
     * @param parameter 参数
     * @param jdbcType  jdbc类型
     * @throws SQLException SQL异常
     */
    @Override
    public void setNonNullParameter(PreparedStatement ps, int i, UUID parameter, org.apache.ibatis.type.JdbcType jdbcType) throws SQLException {
        if (ps != null) {
            ps.setObject(i, parameter);
        }
    }

    /**
     * 获取结果
     *
     * @param str 传参字符串
     * @return 返回UUID结果
     */
    private UUID getValue(String str) {
        return notNull(str) ? UUID.fromString(str) : null;
    }


    /**
     * 非空判断
     *
     * @param arg 参数
     * @return 判断是否不为空
     */
    private boolean notNull(String arg) {
        return (null != arg && !arg.isEmpty());
    }
}

